# DASIFO

We are working on this project, It is a documentation of different tools needed while working in Data Science project!
and we ll enrich it by some use cases that ll simplify and accelerate working by those technologies...
We are looking to create a python library that will regroups:
 - all kind of Databases connections (SQL, NOSQL) and queries examples.
 - it provides some tutorials of APIs: for example conneting to google Drive, cloud....
 - machine learning!
 - deep learning!
 - artificial intelligence!

## We install our library 'dasifo'
```
    pip3 install dasifo
Or
Make sure you are on the right python's envirement variable.
 Download this Lib from github:
    https://github.com/larou2si/dasifo
 To install it locally, run this line in your terminal
    cd dasifo && python3 setup.py sdist bdist_wheel && pip3 install -e .
```

## Uninstall our library 'dasifo'
```
pip3 uninstall dasifo
```

## Databases installation
```
Mysql: https://dev.mysql.com/doc/refman/5.7/en/installing.html
PostgresQL: https://www.postgresql.org/docs/current/admin.html
MongoDB: https://docs.mongodb.com/guides/server/install/

```
## Support & Questions:
```
    Drop a message via mohamed.laroussi.1@esprit.tn
```